@@ -10,6 +10,9 @@ GERAPY_PYPPETEER_DOWNLOAD_TIMEOUT = 30
 GERAPY_PYPPETEER_WINDOW_WIDTH = 1400
 GERAPY_PYPPETEER_WINDOW_HEIGHT = 700
 
+# pyppeteer browser default ua
+GERAPY_PYPPETEER_DEFAULT_USER_AGENT = 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_4) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/83.0.4103.116 Safari/537.36'
+
 # pyppeteer settings
 GERAPY_PYPPETEER_HEADLESS = True
 GERAPY_PYPPETEER_EXECUTABLE_PATH = None
